==> vokoscreen_2.4.0.orig.tar.gz: vokoscreen-2.4.0/language/vokoscreen_id.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="id" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Perangkat sedang sibuk</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Tidak diketahui</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Perangkat</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Digunakan oleh</translation>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Kirim Video terakhir melalui Surat Elektronik</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Kirim satu atau lebih Video melalui Surat Elektronik</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Kirim</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batalkan</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>Silakan pasang sebuah pemutar video</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Anda menemukan Video sebagai lampiran</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Pilih satu atau lebih berkas</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Batas</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>Tampilkan dengan layar penuh</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation>Klik kanan untuk menu</translation>
    </message>
    <message>
        <source>User-defined</source>
        <translation>Ditentukan pengguna</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Perangkat sedang sibuk</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Perangkat</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Digunakan oleh</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Tidak diketahui</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Layar penuh</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Jendela</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Daerah</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Pembesaran</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Baku</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Kodek</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Jangan rekam kursor tetikus</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Jalur video</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Pemutar</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen diminimalkan saat merekam dimulai</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Mulai</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Berhenti</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Berhenti Sejenak</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Putar</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Kirim</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Waktu perekaman</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Ukuran dalam KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Ukuran layar perekaman</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Pengaturan fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Buka Direktori</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Hitung mundur</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Putar Video terakhir</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Kirim Video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Pilih satu atau lebih perangkat</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Frame per detik sebenarnya</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Pergi</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Halaman muka</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Dukungan</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Pengembang</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Bingkai</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donasi</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Program untuk merekam</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Terjemahan</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Kode sumber</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Tampilkan dalam baki sistem</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Versi baru tersedia</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Kodekvideo</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Kodekaudio</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Pilih webcam</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>Dicerminkan</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Layar</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>Semua Layar</translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>Halaman muka Pengembang</translation>
    </message>
</context>
</TS>

==> vokoscreen_2.5.0.orig.tar.gz: vokoscreen-2.5.0/language/vokoscreen_id.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="id" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Perangkat sedang sibuk</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Tidak diketahui</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Perangkat</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Digunakan oleh</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Show Click Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Kirim Video terakhir melalui Surel</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Kirim satu atau lebih Video melalui Surel</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Kirim</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batalkan</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>Silakan pasang sebuah pemutar video</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Anda menemukan Video sebagai lampiran</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Pilih satu atau lebih berkas</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Batas</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>Tampilkan dengan layar penuh</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation>Klik kanan untuk menu</translation>
    </message>
    <message>
        <source>User-defined</source>
        <translation>Ditentukan pengguna</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Perangkat sedang sibuk</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Perangkat</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Digunakan oleh</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Tidak diketahui</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Layar penuh</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Jendela</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Daerah</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Pembesaran</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Baku</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Kodek</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Jangan rekam kursor tetikus</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Jalur video</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Pemutar</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen diminimalkan saat merekam dimulai</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Mulai</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Berhenti</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tangguhkan</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Putar</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Kirim</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Waktu perekaman</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Ukuran dalam KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Ukuran layar perekaman</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Pengaturan fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Buka Direktori</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Hitung mundur</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Putar Video terakhir</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Kirim Video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Pilih satu atau lebih perangkat</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Frame per detik sebenarnya</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Pergi</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Halaman muka</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Dukungan</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Pengembang</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frame</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donasi</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Terjemahan</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Kode sumber</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Tampilkan dalam baki sistem</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Versi baru tersedia</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Kodekvideo</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Kodekaudio</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Pilih webcam</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>Dicerminkan</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Layar</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>Semua Layar</translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>Halaman muka Pengembang</translation>
    </message>
    <message>
        <source>Recorder</source>
        <translation>Perekam</translation>
    </message>
    <message>
        <source>Select recorder</source>
        <translation>Pilih perekam</translation>
    </message>
    <message>
        <source>Hide window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lossless</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
